Documentation
¶
Index ¶
- func BuildJoinedThreadSet(threadMembers []model.ThreadMember) map[int64]struct{}
- func BuildJoinedThreads(joined map[int64]struct{}, channels []model.Channel, ...) map[int64]map[int64][]int64
- func FilterGuildLastMessages(glms map[int64]map[int64]int64, channels []model.Channel) map[int64]map[int64]int64
- func FilterThreadLastMessages(joined map[int64]struct{}, channels []model.Channel, ...) map[int64]int64
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BuildJoinedThreadSet ¶
func BuildJoinedThreadSet(threadMembers []model.ThreadMember) map[int64]struct{}
BuildJoinedThreadSet deduplicates thread membership rows into a thread-id set.
func BuildJoinedThreads ¶
func BuildJoinedThreads(joined map[int64]struct{}, channels []model.Channel, guildChannels []model.GuildChannel) map[int64]map[int64][]int64
BuildJoinedThreads groups joined thread IDs as guild_id -> parent_channel_id -> sorted thread IDs.
func FilterGuildLastMessages ¶
func FilterGuildLastMessages(glms map[int64]map[int64]int64, channels []model.Channel) map[int64]map[int64]int64
FilterGuildLastMessages keeps only live non-thread channels from the guild last-message snapshot.
func FilterThreadLastMessages ¶
func FilterThreadLastMessages(joined map[int64]struct{}, channels []model.Channel, glms map[int64]map[int64]int64) map[int64]int64
FilterThreadLastMessages keeps only live joined threads from the guild last-message snapshot. Threads without a parent are ignored so this map stays aligned with BuildJoinedThreads.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.